<?php
/*****************************************************************************
 * cmi (Copyright Management Information) Plugin for Geeklog                 *
 * Copyright (C) 2004 by the following authors:                              *
 * Authors: Mike Green <mikey at badpenguins dot com>                        *
 *****************************************************************************
 * index.php                                                                 *
 * This file provides the administration interface for the Geeklog cmi       *
 * plugin.                                                                   *
 *****************************************************************************
 * This program is free software; you can redistribute it and/or modify it   *
 * under the terms of the GNU General Public License as published by the     *
 * Free Software Foundation; either version 2 of the License, or (at your    *
 * option) any later version.                                                *
 *                                                                           *
 * This program is distributed in the hope that it will be useful, but       *
 * WITHOUT ANY WARRANTY; without even the implied warranty of                *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General *
 * Public License for more details.                                          *
 *                                                                           *
 * You should have received a copy of the GNU General Public License along   *
 * with this program; if not, write to the Free Software Foundation, Inc.,   *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.                 *
 *****************************************************************************/
require_once('../../../lib-common.php');
require_once('../../auth.inc.php');

if (!SEC_hasRights('cmi.add,cmi.delete,cmi.edit,cmi.list','OR')) {
    $display = COM_siteHeader('menu');
    $display .= COM_startBlock($LANG_CMI[1]);
    $display .= $LANG_CMI[2];
    $display .= COM_endBlock();
    $display .= COM_siteFooter();
    $msg  = "User {$_USER['username']} tried to illegally access the CMI ";
    $msg .= "administration screen.  IP: " . $_SERVER['REMOTE_ADDR'];
    COM_accessLog($msg);
    echo $display;
    exit;
}

/*****************************************************************************
 * Displays a form to gather input needed to add a new license.              *
 *****************************************************************************/
function cmi_licenseAddForm() {

cmi_validateLicenseAdd('',false);

global $_TABLES, $LANG_STATIC, $LANG_CMI, $_CONF;

$retval = '';

$TPL = new Template($_CONF['path'] . 'plugins/cmi/templates/admin');
$TPL->set_file('page','license.add.thtml');
$TPL->set_var('start_block_add',COM_startBlock($LANG_CMI[58]));
$TPL->set_var('top_links',cmi_generateAdminLinks());
$TPL->set_var('submit_url',COM_buildURL($_CONF['site_admin_url'])
              . '/plugins/cmi/index.php');
$TPL->set_var('end_block',COM_endBlock());
$TPL->parse('output','page');
$retval .= $TPL->finish($TPL->get_var('output'));

return $retval;

}

/*****************************************************************************
 * Displays a license for confirmation before deleting                       *
 *****************************************************************************/
function cmi_licenseDeleteForm($pvars='') {

cmi_validateLicenseDelete($pvars,false);

global $_TABLES, $LANG_STATIC, $LANG_CMI, $_CONF;

$license_id = addslashes($pvars['lid']);
$sql    = "SELECT * FROM {$_TABLES['cmi_licenses']} ";
$sql   .= "where lid=$license_id LIMIT 1";
$result = DB_query($sql);
$nrows  = DB_numRows($result);
// Should have been confirmed by cmi_validateLicenseDelete, but
// double check here.
if ($nrows !== 1) {
    echo "Error: license does not exist";
    exit();
    }
$A      = DB_fetchArray($result);
$l_name = stripslashes($A['license_name']);
$l_ver  = stripslashes($A['license_version']);
$l_url  = stripslashes($A['license_url']);
$l_text = stripslashes(nl2br($A['license_text']));
$l_date = $A['tstamp'];

$retval = '';

$TPL = new Template($_CONF['path'] . 'plugins/cmi/templates/admin');
$TPL->set_file('page','license.delete.thtml');
$TPL->set_var('start_block_view',COM_startBlock($LANG_CMI[59]));
$TPL->set_var('license_id',$license_id);
$TPL->set_var('license_name',$l_name);
$TPL->set_var('license_version',$l_ver);
$TPL->set_var('license_url',$l_url);
$TPL->set_var('license_text',$l_text);
$TPL->set_var('license_date',$l_date);
$TPL->set_var('top_links',cmi_generateAdminLinks());
$TPL->set_var('submit_url',COM_buildURL($_CONF['site_admin_url'])
              . '/plugins/cmi/index.php');
$TPL->set_var('end_block',COM_endBlock());

$TPL->parse('output','page');
$retval .= $TPL->finish($TPL->get_var('output'));

return $retval;

}

/*****************************************************************************
 * Displays a license for editing                                            *
 *****************************************************************************/
function cmi_licenseEditForm($license_id='') {

cmi_validateLicenseEdit(array('lid'=>$license_id),false);

global $_TABLES, $LANG_STATIC, $LANG_CMI, $_CONF;

$license_id = addslashes($license_id);
// query the license
$sql    = "SELECT * FROM {$_TABLES['cmi_licenses']} ";
$sql   .= "where lid=$license_id LIMIT 1";
$result = DB_query($sql);
$nrows  = DB_numRows($result);
// Should be caught by vmi_validateLicenseEdit(), but catch it
// here just in case.
if (DB_error() or $nrows !== 1) {
    echo "Cannot edit non-existent license";
    exit();
    }

$A      = DB_fetchArray($result);
$l_name = stripslashes($A['license_name']);
$l_ver  = stripslashes($A['license_version']);
$l_url  = stripslashes($A['license_url']);
$l_text = stripslashes($A['license_text']);

$retval = '';

$TPL = new Template($_CONF['path'] . 'plugins/cmi/templates/admin');
$TPL->set_file('page','license.edit.thtml');
$TPL->set_var('start_block_edit',COM_startBlock($LANG_CMI[62]));
$TPL->set_var('lid',$license_id);
$TPL->set_var('license_name',$l_name);
$TPL->set_var('license_version',$l_ver);
$TPL->set_var('license_url',$l_url);
$TPL->set_var('license_text',$l_text);
$TPL->set_var('top_links',cmi_generateAdminLinks());
$TPL->set_var('submit_url',COM_buildURL($_CONF['site_admin_url'])
              . '/plugins/cmi/index.php');
$TPL->set_var('end_block',COM_endBlock());
if (SEC_hasRights('cmi.delete') and $license_id != 1) {
    $TPL->set_var('delete_option',
        '<input type="submit" name="mode" value="delete">');
    } else {
    $TPL->set_var('delete_option','');
    }

$TPL->parse('output','page');
$retval .= $TPL->finish($TPL->get_var('output'));

return $retval;

}

/*****************************************************************************
 * Displays a list of licenses that are in the database                      *
 *****************************************************************************/
function cmi_licenseListForm() {

global $_TABLES, $LANG_STATIC, $LANG_CMI, $_CONF;

if (!SEC_hasRights('cmi.list')) {
    $display = COM_siteHeader('menu');
    $display .= COM_startBlock($LANG_CMI[1]);
    $display .= $LANG_CMI[2];
    $display .= COM_endBlock();
    $display .= COM_siteFooter();
    $msg  = "User {$_USER['username']} tried to access CMI plugin functions ";
    $msg .= "without cmi.list perms.  IP: " . $_SERVER['REMOTE_ADDR'];
    COM_accessLog($msg);
    echo $display;
    exit();
    }

$retval = '';

$TPL = new Template($_CONF['path'] . '/plugins/cmi/templates/admin');
$TPL->set_file(array('list'=>'license.list.thtml',
                     'row'=>'license.list.row.thtml'));
$TPL->set_var('start_block_list',COM_startBlock($LANG_CMI[50]));
$TPL->set_var('lang_instructions',$LANG_CMI[52]);
$TPL->set_var('top_links',cmi_generateAdminLinks());

// Build test that will go in the description.
if (SEC_hasRights('cmi.add')) {
    $TPL->set_var('add_description','To add a new license click on the '
                  . '"Add License" link above.');
    } else {
    $TPL->set_var('add_description','');
    }
if (SEC_hasRights('cmi.delete,cmi.edit','OR')) {
    $TPL->set_var('edit_description','To modify or delete a license, click '
                  . 'on the license number.');
    } else {
    $TPL->set_var('edit_description','');
    }

$perpage = 50;
if ($page <= 0) { $page = 1; }

$sql      = "SELECT COUNT(*) AS count FROM {$_TABLES['cmi_licenses']}";
$result   = DB_query($sql);
$C        = DB_fetchArray ($result);
$numpages = ceil ($C['count'] / $perpage);
if ($page > $numpages) {
    $page = 1;
    }
$start = ($page - 1) * $perpage;

$sql    = "SELECT * FROM {$_TABLES['cmi_licenses']} ORDER BY ";
$sql   .= "license_name DESC LIMIT $start,$perpage";
$result = DB_query($sql);
$nrows  = DB_numRows ($result);
if ($nrows > 0) {
    for ($i = 1; $i <= $nrows; $i++) {
        $A            = DB_fetchArray($result);
        $row_num      = $i + $start;
        $license_id   = $A['lid'];
        $license_name = stripslashes($A['license_name']);
        $license_ver  = stripslashes($A['license_version']);
        $license_url  = $A['license_url'];
        $license_time = $A['tstamp'];

        $license_edit_href =
            '<a href="' . COM_buildURL($_CONF['site_admin_url'])
            . '/plugins/cmi/?mode=edit&amp;ot=license&amp;lid='
            . $license_id . '">' . $row_num . '</a>';

        if (SEC_hasRights('cmi.edit,cmi.delete','OR')) {
            $TPL->set_var('license_edit_href',$license_edit_href);
            } else {
            $TPL->set_var('license_edit_href',$row_num);
            }

        $license_view_href =
            '<a href="' . COM_buildURL($_CONF['site_admin_url']
            . '/plugins/cmi/?mode=view&amp;ot=license&amp;lid='
            . $A['lid']) . '">' . $license_name . '</a>';
        $TPL->set_var('license_view_href',$license_view_href);

        if (!empty($license_url)) {
            $junk    = parse_url($license_url);
            $urlhost = $junk['host'];
            $license_href = '<a href="' . COM_buildURL($license_url)
                . '" target="_new">' . $urlhost . '</a>';
            } else {
            $license_href = '';
            }
        $TPL->set_var('license_href',$license_href);

        $TPL->set_var('license_version',stripslashes($A['license_version']));
        $TPL->set_var('license_date',$A['tstamp']);
        $TPL->set_var ('row_number', $row_num);
        $TPL->parse('list_item','row',true);
    }

    $TPL->set_var ('lang_nolicenses_msg', '');
    $baseurl = $_CONF['site_admin_url'] . '/plugins/cmi/index.php';
    if ($numpages > 1) {
        $TPL->set_var ('google_paging',
        COM_printPageNavigation ($baseurl, $page, $numpages));
        } else {
        $TPL->set_var('google_paging', '');
        }
    } else {
    $TPL->set_var('lang_nolicenses_msg',$LANG_CMI[56]);
    $TPL->set_var('list_item','');
    $TPL->set_var('google_paging','');
    }

$TPL->set_var('end_block',COM_endBlock());
$retval .= $TPL->parse('output','list');

return $retval;

}

/*****************************************************************************
 * Displays a license for viewing                                            *
 *****************************************************************************/
function cmi_licenseViewForm($license_id='') {

global $_TABLES, $LANG_STATIC, $LANG_CMI, $_CONF;

if (!SEC_hasRights('cmi.list')) {
    $display  = COM_siteHeader('menu');
    $display .= COM_startBlock($LANG_CMI[1]);
    $display .= $LANG_CMI[2];
    $display .= COM_endBlock();
    $display .= COM_siteFooter();
    $msg  = "User {$_USER['username']} tried to access CMI plugin functions ";
    $msg .= "without cmi.list perms. IP: " . $_SERVER['REMOTE_ADDR'];
    COM_accessLog($msg);
    echo $display;
    exit();
    }

$license_id   = addslashes($license_id);
$invalid_msg  = COM_siteHeader('menu');
$invalid_msg .= COM_startBlock($LANG_CMI[60]);
$invalid_msg .= $LANG_CMI[61];
$invalid_msg .= COM_endBlock();
$invalid_msg .= COM_siteFooter();

if (!is_numeric($license_id)) {
    echo $invalid_msg;
    exit();
    }

// query the license
$sql    = "SELECT * FROM {$_TABLES['cmi_licenses']} ";
$sql   .= "where lid=$license_id LIMIT 1";
$result = DB_query($sql);
$nrows  = DB_numRows($result);
if ($nrows !== 1) {
    echo $invalid_msg;
    exit();
    }

$A      = DB_fetchArray($result);
$l_name = stripslashes($A['license_name']);
$l_ver  = stripslashes($A['license_version']);
$l_url  = stripslashes($A['license_url']);
$l_text = stripslashes(nl2br($A['license_text']));
$l_date = $A['tstamp'];

$retval = '';

$TPL = new Template($_CONF['path'] . 'plugins/cmi/templates/admin');
$TPL->set_file('page','license.view.thtml');
$TPL->set_var('start_block_view',COM_startBlock($LANG_CMI[59]));
$TPL->set_var('license_name',$l_name);
$TPL->set_var('license_version',$l_ver);
$TPL->set_var('license_url',$l_url);
$TPL->set_var('license_text',$l_text);
$TPL->set_var('license_date',$l_date);
$TPL->set_var('top_links',cmi_generateAdminLinks());
$TPL->set_var('end_block',COM_endBlock());
$TPL->parse('output','page');
$retval .= $TPL->finish($TPL->get_var('output'));

return $retval;

}

/*****************************************************************************
 * main flow starts here                                                     *
 * $mode is for action: add, delete, edit, list, view                        *
 * $lid is for object id                                                     *
 * $ot is for object type: license, c = comment, a = attribution             *
 *****************************************************************************/
isset($_POST['mode']) ? $mode = $_POST['mode'] : $mode = $_GET['mode'];
isset($_POST['lid'])  ? $lid  = $_POST['lid']  : $lid  = $_GET['lid'];
isset($_POST['ot'])   ? $ot   = $_POST['ot']   : $ot   = $_GET['ot'];
isset($_POST['cid'])  ? $cid  = $_POST['cid']  : $cid  = $_GET['cid'];
isset($_POST['aid'])  ? $aid  = $_POST['aid']  : $aid  = $_GET['aid'];

$display = '';

switch($mode) {
    // add
    case "add":
        switch($ot) {
            // add a license
            case "license":
                if ($_POST['submit'] == "save") {
                    $display .= cmi_licenseAdd($_POST);
                    } else {
                    $display .= COM_siteHeader('menu');
                    $display .= cmi_licenseAddForm();
                    $display .= COM_siteFooter();
                    }
            break;
            default:
                die("Ain't done yet!");
            break;
            }
    break;
    // delete
    case "delete":
        switch($ot) {
            case "license":
                if ($_POST['submit'] == "confirm") {
                    $display .= cmi_licenseDelete($_POST);
                    } else {
                    $display .= COM_siteHeader();
                    $display .= cmi_licenseDeleteForm($_POST);
                    $display .= COM_siteFooter();
                    }
            break;
            default:
                die("Ain't done yet!");
            break;
            }
    break;
    // edit
    case "edit":
        switch($ot) {
            case "cmi":
                if ($_POST['submit'] == "save") {
                    $display .= COM_siteHeader('menu');
                    $display .= cmi_commentEdit($cid,$lid,$aid);
                    $display .= COM_SiteFooter();
                } else {
                    $display .= COM_siteHeader('menu');
                    $display .= cmi_commentEditForm($cid,$lid,$aid);
                    $display .= COM_SiteFooter();
                }
            break;
            case "license":
            default:
                if ($_POST['submit'] == "save") {
                    $display .= cmi_licenseEdit($_POST);
                    } else {
                    $display .= COM_siteHeader('menu');
                    $display .= cmi_licenseEditForm($_GET['lid']);
                    $display .= COM_siteFooter();
                    }
            break;
            }
    break;
    // set (user function)
    case "set":
        switch($ot) {
            case "license":
                if (cmi_setLicense($_POST)) {
                    die("OK, set the license");
                    } else {
                    die("Hmm, failed to set the license");
                    }
            break;
            default:
                die("Access Denied");
            break;
            }
    break;
    // view
    case "view":
        switch($ot) {
            case "license":
                $display .= COM_siteHeader('menu');
                $display .= cmi_licenseViewForm($lid);
                $display .= COM_siteFooter();
            break;
            default:
                die("Ain't done yet!");
            break;
            }
    break;
    // default is list
    case "list":
    default:
        switch($ot) {
            // attribution
            case "attribution":
            // comment
            case "comment":
                die("Ain't done yet!");
            break;
            // default/license
            case "license":
            default:
                $display .= COM_siteHeader('menu');
                $display .= cmi_licenseListForm();
                $display .= COM_siteFooter();
            break;
            }
    break;
    }

echo $display;

?>
