<?php
/*****************************************************************************
 * cmi (Copyright Management Information) Plugin for Geeklog                 *
 * Copyright (C) 2004 by the following authors:                              *
 * Authors: Mike Green <mikey at badpenguins dot com>                        *
 *****************************************************************************
 * install.php                                                               *
 * This file installs and removes the data structures for the cmi plugin for *
 * geeklog.                                                                  *
 *****************************************************************************
 * This program is free software; you can redistribute it and/or modify it   *
 * under the terms of the GNU General Public License as published by the     *
 * Free Software Foundation; either version 2 of the License, or (at your    *
 * option) any later version.                                                *
 *                                                                           *
 * This program is distributed in the hope that it will be useful, but       *
 * WITHOUT ANY WARRANTY; without even the implied warranty of                *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General *
 * Public License for more details.                                          *
 *                                                                           *
 * You should have received a copy of the GNU General Public License along   *
 * with this program; if not, write to the Free Software Foundation, Inc.,   *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.                 *
 *****************************************************************************/
require_once('../../../lib-common.php');
require_once($_CONF['path'] . 'plugins/cmi/language/english.php');
require_once($_CONF['path'] . 'plugins/cmi/config.php');
require_once($_CONF['path'] . 'plugins/cmi/functions.inc');

//
// Only let Root users access this page
//
if (!SEC_inGroup('Root')) {
    $msg  = "Someone has tried to illegally access the cmi install/uninstall ";
    $msg .= "page.  User id: {$_USER['uid']}, Username: {$_USER['username']},";
    $msg .= " IP: $REMOTE_ADDR";
    COM_errorLog($msg,1);
    $display  = COM_siteHeader();
    $display .= COM_startBlock($LANG_CMI[1]);
    $display .= $LANG_CMI[2];
    $display .= COM_endBlock();
    $display .= COM_siteFooter();
    echo $display;
    exit;
    }

if ($http_get_vars['override'] === true) {
    $override = true;
    } else {
    $override = false;
    }

if (!in_array(VERSION,$_CMI_CONF['compat']) and !$override === true) {
    $override_url  = '<a href="' . $_CONF['site_admin_url'] . '/plugins/cmi/';
    $override_url .= 'install.php?cmd=install&override=true">' . $LANG_CMI[6];
    $override_url .= '</a>';
    COM_errorLog($LANG_CMI[4],1);
    $display  = COM_siteHeader();
    $display .= COM_startBlock($LANG_CMI[5]);
    $display .= $LANG_CMI[4];
    $display .= '<p align="center">You are free to ' . $override_url . ' and ';
    $display .= 'continue with the installation.';
    $display .= '</p>';
    $display .= COM_endBlock();
    $display .= COM_siteFooter();
    echo $display;
    exit();
    }

/*****************************************************************************
 * plugin_install_cmi()                                                      *
 *****************************************************************************/
function plugin_install_cmi() {

global $_TABLES, $_CONF, $_CMI_CONF, $LANG_CMI;
COM_errorLog($LANG_CMI[3] . " Version " . $_CMI_CONF['version'],1);

// license information table
$table = $_TABLES['cmi_licenses'];
$sql = 'CREATE TABLE ' . $table . '(
    lid tinyint(4) unsigned NOT NULL auto_increment,
    license_name varchar(255) default \'\' not null,
    license_version varchar(255) default null,
    license_url varchar(255) default \'\' null,
    license_text longtext null,
    tstamp datetime default null,
    primary key(lid),
    unique key license_name(license_name)
)';

$msg = "Attempting to install $table table for cmi plugin";
COM_errorLog($msg,1);
DB_query($sql,1);
if (DB_error()) {
    return false;
    }

COM_errorLog('...success',1);
$steps['createtable1'] = true;

// alter the comments table
$sql  = 'ALTER TABLE ' . $_TABLES['comments'];
$sql .= ' ADD lid TINYINT(4) UNSIGNED DEFAULT \'1\' NOT NULL';
$msg = "Attempting to alter the comments table for the cmi plugin";
COM_errorLog($msg,1);
DB_query($sql,1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    }
COM_errorLog('...success',1);
$steps['altercommentstable'] = true;

// add index to the comments lid field
$sql  = 'ALTER TABLE ' . $_TABLES['comments'];
$sql .= ' ADD INDEX comments_lid(lid)';
$msg  = 'Attempting to add index to comments table lid column for the cmi ';
$msg .= 'plugin';
COM_errorLog($msg,1);
DB_query($sql,1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    }
COM_errorLog('...success',1);
$steps['commentstableindex'] = true;

// alter the stories table
$sql  = 'ALTER TABLE ' . $_TABLES['stories'];
$sql .= ' ADD lid TINYINT(4) UNSIGNED DEFAULT \'1\' NOT NULL';
$msg = "Attempting to alter the stories table for the cmi plugin";
COM_errorLog($msg,1);
DB_query($sql,1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    }
COM_errorLog('...success',1);
$steps['alterstoriestable'] = true;

// add index to the stories lid field
$sql  = 'ALTER TABLE ' . $_TABLES['stories'];
$sql .= ' ADD INDEX comments_lid(lid)';
$msg  = 'Attempting to add index to stories table lid column for the cmi ';
$msg .= 'plugin';
COM_errorLog($msg,1);
DB_query($sql,1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    }
COM_errorLog('...success',1);
$steps['storiestableindex'] = true;

// alter the submissions table
$sql  = 'ALTER TABLE ' . $_TABLES['storysubmission'];
$sql .= ' ADD lid TINYINT(4) UNSIGNED DEFAULT \'1\' NOT NULL';
$msg = "Attempting to alter the submission table for the cmi plugin";
COM_errorLog($msg,1);
DB_query($sql,1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    }
COM_errorLog('...success',1);
$steps['altersubmissiontable'] = true;


// Create the admin/mod groups
$a_group    = $_CMI_CONF['cmi_admin_group'];
$a_group_id = DB_getItem($_TABLES['groups'], 'grp_id', "grp_name='$a_group'");
if (is_numeric($a_group_id)) {
    $msg  = "Warning, group already exists: $a_group.  Aborting, we don't ";
    $msg .= "want to hand out privs to an existing group.";
    COM_errorLog($msg,1);
    plugin_uninstall_cmi($steps);
    return false;
    }

COM_errorLog("Attempting to create group: $a_group", 1);
$sql  = "insert into " . $_TABLES['groups'] . "(grp_name,grp_descr) ";
$sql .= "values('$a_group','Users in this group can administrate ";
$sql .= "Copyright Management Information')";
DB_query($sql,1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
$a_group_id = DB_insertId();
COM_errorLog('...success',1);
$steps['insertadmingroup'] = true;

// Create the admin/mod groups
$m_group    = $_CMI_CONF['cmi_mod_group'];
$m_group_id = DB_getItem($_TABLES['groups'], 'grp_id', "grp_name='$m_group'");
if (is_numeric($m_group_id)) {
    $msg  = "Warning, group already exists: $m_group.  Aborting, we don't ";
    $msg .= "want to hand out privs to an existing group.";
    COM_errorLog($msg,1);
    plugin_uninstall_cmi($steps);
    return false;
    }

COM_errorLog("Attempting to create group: $m_group", 1);
$sql  = "insert into " . $_TABLES['groups'] . "(grp_name,grp_descr) ";
$sql .= "values('$m_group','Users in this group can moderate Copyright ";
$sql .= "Management Information')";
DB_query($sql,1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
$m_group_id = DB_insertId();
COM_errorLog('...success',1);
$steps['insertmodgroup'] = true;

// add granular perms
// add perm
COM_errorLog('Attempting to add cmi.add perm',1);
DB_query("INSERT INTO {$_TABLES['features']} (ft_name,ft_descr) "
    . "VALUES ('cmi.add','Access to Add to CMI License list')",1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
$add_id = DB_insertId();
COM_errorLog('...success',1);
$steps['insertedaddperm'] = true;

// delete perm
COM_errorLog('Attempting to add cmi.delete perm',1);
DB_query("INSERT INTO {$_TABLES['features']} (ft_name,ft_descr) "
    . "VALUES ('cmi.delete','Access to Delete from CMI License list')",1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
$delete_id = DB_insertId();
COM_errorLog('...success',1);
$steps['inserteddeleteperm'] = true;

// edit perm
COM_errorLog('Attempting to add cmi.edit perm',1);
DB_query("INSERT INTO {$_TABLES['features']} (ft_name,ft_descr) "
    . "VALUES ('cmi.edit','Access to Edit CMI Licenses')",1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
$edit_id = DB_insertId();
COM_errorLog('...success',1);
$steps['insertededitperm'] = true;

// list perm to all users
COM_errorLog('Attempting to add cmi.list perm',1);
DB_query("INSERT INTO {$_TABLES['features']} (ft_name,ft_descr) "
    . "VALUES ('cmi.list','Access to List CMI Licenses')",1);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
$list_id = DB_insertId();
COM_errorLog('...success',1);
$steps['insertedlistperm'] = true;

// grant add perms to cmi_admins
COM_errorLog("Attempting to grant $a_group group cmi.add perms",1);
$sql  = "INSERT INTO {$_TABLES['access']} (acc_ft_id,acc_grp_id) ";
$sql .= "VALUES ($add_id, $a_group_id)";
DB_query($sql);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
COM_errorLog('...success',1);
$steps['grantadminadd'] = true;

// grant delete perms to cmi_admins
COM_errorLog("Attempting to grant $a_group group cmi.delete perms",1);
$sql  = "INSERT INTO {$_TABLES['access']} (acc_ft_id,acc_grp_id) ";
$sql .= "VALUES ($delete_id, $a_group_id)";
DB_query($sql);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
COM_errorLog('...success',1);
$steps['grantadmindelete'] = true;

// grant edit perms to cmi_admins
COM_errorLog("Attempting to grant $a_group group cmi.edit perms",1);
$sql  = "INSERT INTO {$_TABLES['access']} (acc_ft_id,acc_grp_id) ";
$sql .= "VALUES ($edit_id, $a_group_id)";
DB_query($sql);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
COM_errorLog('...success',1);
$steps['grantadminedit'] = true;

// grant list perms to all users
COM_errorLog("Attempting to grant All Users group cmi.list perms",1);
$sql  = "INSERT INTO {$_TABLES['access']} (acc_ft_id,acc_grp_id) ";
$sql .= "VALUES ($list_id, 2)";
DB_query($sql);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
COM_errorLog('...success',1);
$steps['grantalllist'] = true;

// grant edit perms to cmi_mods
COM_errorLog("Attempting to grant $m_group group cmi.edit perms",1);
$sql  = "INSERT INTO {$_TABLES['access']} (acc_ft_id,acc_grp_id) ";
$sql .= "VALUES ($edit_id, $m_group_id)";
DB_query($sql);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
COM_errorLog('...success',1);
$steps['grantmodedit'] = true;

// Grant root users god status
$msg  = "Attempting to add all users in Root group to $a_group group";
COM_errorLog($msg,1);
$sql  = "INSERT INTO {$_TABLES['group_assignments']} ";
$sql .= "VALUES($a_group_id,NULL,1)";
DB_query($sql);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
COM_errorLog('...success',1);
$steps['addedrootuserstoadmin'] = true;

// Grant root users mod status
$msg  = "Attempting to add all users in Root group to $m_group group";
COM_errorLog($msg,1);
$sql  = "INSERT INTO {$_TABLES['group_assignments']} ";
$sql .= "VALUES($m_group_id,NULL,1)";
DB_query($sql);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
    }
COM_errorLog('...success',1);
$steps['addedrootuserstomod'] = true;

// add sample licenses
$msg  = "Attempting to add sample licenses";
COM_errorLog($msg,1);
$table = $_TABLES['cmi_licenses'];
$samples   = array();
$samples[] = array('Contact Author','','');
$samples[] = array('CCL Attribution','2.0',
                   'http://creativecommons.org/licenses/by/2.0/');
$samples[] = array('CCL Attribution-NoDerivs','2.0',
                   'http://creativecommons.org/licenses/by-nd/2.0/');
$samples[] = array('CCL Attribution-NonCommercial-NoDerivs','2.0',
                   'http://creativecommons.org/licenses/by-nc-nd/2.0/');
$samples[] = array('CCL Attribution-NonCommerical','2.0',
                   'http://creativecommons.org/licenses/by-nc/2.0/');
$samples[] = array('CCL Attribution-NonCommercial-ShareAlike','2.0',
                   'http://creativecommons.org/licenses/by-nc-sa/2.0/');
$samples[] = array('CCL Attribution-ShareAlike','2.0',
                   'http://creativecommons.org/licenses/by-sa/2.0/');
$samples[] = array('GNU Free Documentation License','1.2',
                   'http://www.gnu.org/licenses/fdl.html');
$sql = array();
foreach($samples as $sample) {
    $sql[] = "INSERT INTO $table(license_name,license_version,license_url,tstamp) "
             . "VALUES('{$sample[0]}','{$sample[1]}','{$sample[2]}',now())";
    }

foreach ($sql as $query) {
    DB_query($query);
    if (DB_error()) {
        plugin_uinstall_cmi($steps);
        return false;
        exit();
        }
    }

// register the plugin with Geeklog
if (DB_count($_TABLES['plugins'],'pi_name','cmi') > 0) {
    COM_errorLog('Attempting to remove old cmi prior to adding an updated entry',1);
    DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'cmi'");
    if (DB_error()) {
        plugin_uninstall_cmi($steps);
        return false;
        exit();
        }
    COM_errorLog('...success',1);
    }

COM_errorLog('Registering cmi plugin with Geeklog', 1);
$sql  = "insert into " . $_TABLES['plugins'] . "(pi_name,pi_version,";
$sql .= "pi_gl_version,pi_homepage,pi_enabled) values('cmi','";
$sql .= $_CMI_CONF['version'] . "','" . VERSION . "','";
$sql .= $_CMI_CONF['homepage'] . "',1)";
DB_query($sql);
if (DB_error()) {
    plugin_uninstall_cmi($steps);
    return false;
    exit();
}
COM_errorLog('...success',1);
COM_errorLog('Succesfully installed the CMI Plugin!',1);

return true;

}

/*
MAIN:  OK, I wanted to keep this simple so this is how this works.  When ran for the first
time, this file will attempt to install the datastructures immediately.  When that is complete,
it will insert a record into the Geeklog vars table (name = 'journal', value = 1) which will
lock this file from being executed at by anyone.

If you want to remove this plugin you would set the value in that record to 0 and then this script
will uninstall the plugin.  All this is outlined in the INSTALL and UNINSTALL documents.
*/
$display = COM_siteHeader();
if ( $_GET['action'] == 'install') {
    if (plugin_install_cmi()) {
        $display .= COM_startBlock($LANG_CMI[7]);
        $display .= $LANG_CMI[8];
        $display .= COM_endBlock();
    } else {
        // Error occured
        $display .= COM_startBlock($LANG_CMI[9]);
        $display .= $LANG_CMI[10];
        $display .= COM_endBlock();
    }
} elseif ( $_GET['action'] == 'uninstall' ) {
    if (plugin_uninstall_cmi()) {
        // Uninstall worked
        $display .= COM_startBlock($LANG_CMI[11]);
        $display .= $LANG_CMI[12];
        $display .= COM_endBlock();
    } else {
        // Uninstall failed
        $display .= COM_startBlock($LANG_CMI[13]);
        $display .= $LANG_CMI[14];
        $display .= COM_endBlock();
    }
}

$display .= COM_siteFooter();

echo $display;

?>
