<?php
/*****************************************************************************
 * cmi (Copyright Management Information) Plugin for Geeklog                 *
 * Copyright (C) 2004 by the following authors:                              *
 * Authors: Mike Green <mikey at badpenguins dot com>                        *
 *****************************************************************************
 * license.php                                                               *
 * This file provides the user interface for the Geeklog cmi plugin.         *
 *****************************************************************************
 * This program is free software; you can redistribute it and/or modify it   *
 * under the terms of the GNU General Public License as published by the     *
 * Free Software Foundation; either version 2 of the License, or (at your    *
 * option) any later version.                                                *
 *                                                                           *
 * This program is distributed in the hope that it will be useful, but       *
 * WITHOUT ANY WARRANTY; without even the implied warranty of                *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General *
 * Public License for more details.                                          *
 *                                                                           *
 * You should have received a copy of the GNU General Public License along   *
 * with this program; if not, write to the Free Software Foundation, Inc.,   *
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.                 *
 *****************************************************************************/
require_once('lib-common.php');

if (!SEC_hasRights('cmi.add,cmi.delete,cmi.edit,cmi.list','OR')) {
    $display = COM_siteHeader('menu');
    $display .= COM_startBlock($LANG_CMI[1]);
    $display .= $LANG_CMI[2];
    $display .= COM_endBlock();
    $display .= COM_siteFooter();
    $msg  = "User {$_USER['username']} tried to illegally access the CMI ";
    $msg .= "user interface screen.  IP: " . $_SERVER['REMOTE_ADDR'];
    COM_accessLog($msg);
    echo $display;
    exit;
}

/*****************************************************************************
 * cmi_setLicense()                                                          *
 * Processes requests to update licenses.                                    *
 * Users cannot change their own licensing terms.  If they want to do that,  *
 * they can repost the same comment with different licensing terms.  Those   *
 * with cmi.edit perms can.                                                  *
 *****************************************************************************/
function cmi_setLicense($pvars='') {

global $_USER, $_TABLES;

$lid = addslashes($pvars['lid']);
$cid = addslashes($pvars['cid']);

if (!SEC_hasRights("cmi.edit")) {
    $msg  = "User {$_USER['username']} attempted to edit licensing on ";
    $msg .= "comment $cid without cmi.edit perms";
    COM_errorlog($msg,1);
    return false;
    }

if (!is_numeric($lid) or !is_numeric($cid)) {
    $msg  = "User {$_USER['username']} attempted to edit licensing on ";
    $msg .= "a comment with an invalid license id ($lid) or comment id ";
    $msg .= "($cid)";
    COM_errorlog($msg,1);
    return false;
    }

// verify the comment exists
$d_cid = DB_getItem($_TABLES['comments'],'cid',"cid=$cid limit 1");
if (DB_error() or $d_cid !== $cid) {
    $msg  = "User {$_USER['username']} attempted to edit licensing on ";
    $msg .= "a non existent comment ($cid)";
    COM_errorlog($msg,1);
    return false;
    }
// verify the license id exists
$lic_name = DB_getItem($_TABLES['cmi_licenses'],'license_name',"lid=$lid limit 1");
if (DB_error() or $lic_name == '') {
    $msg  = "User {$_USER['username']} attempted to change licensing on ";
    $msg .= "a comment ($cid) with an invalid license id ($lid)";
    COM_errorlog($msg,1);
    return false;
    }

$sql  = "UPDATE {$_TABLES['comments']} set lid=$lid ";
$sql .= "where cid=$cid limit 1";
DB_query($sql);
if (DB_error()) {
    $msg  = "User {$_USER['username']} attempt to change licensing on ";
    $msg .= "comment ($cid) to license id ($lid) failed";
    COM_errorlog($msg,1);
    return false;
    }

$msg  = "User {$_USER['username']} changed license on ";
$msg .= "comment ($cid) to license id: $lid (" . stripslashes($lic_name) . ")";
COM_errorlog($msg,1);

return true;

}

/*****************************************************************************
 * main flow starts here                                                     *
 * $mode is for action: add, delete, edit, list, view                        *
 * $lid is for object id                                                     *
 * $ot is for object type: license, c = comment, a = attribution             *
 *****************************************************************************/
isset($_POST['mode']) ? $mode = $_POST['mode'] : $mode = $_GET['mode'];

$display = '';

switch($mode) {
    // set (user function)
    case "set":
        if (cmi_setLicense($_POST)) {
            $display = COM_refresh($HTTP_REFERER);
            } else {
            $display  = COM_siteHeader('menu');
            $display .= COM_startBlock("License Change Failure");
            $display .= "Failed to change the licensing, see the error.log";
            $display .= "for more information.  Click ";
            $display .= "<a href=\"$HTTP_REFERER\">here</a> to return to ";
            $display .= "comment.";
            $display .= COM_endBlock();
            $display .= COM_siteFooter();
            }
    break;
    // attrib (set attribution)
    case "attrib":
        die("blah");
    break;
    default:
        die("Access Denied");
    break;
    }

echo $display;

?>
